@@ -6,10 +6,10 @@ use warnings;
 
 BEGIN {
 	$lexical::underscore::AUTHORITY = 'cpan:TOBYINK';
-	$lexical::underscore::VERSION   = '0.003';
+	$lexical::underscore::VERSION   = '0.004';
 }
 
-use if $] >= 5.009, PadWalker => qw( peek_my );
+use if ($] >= 5.009 && $] < 5.023), PadWalker => qw( peek_my );
 BEGIN {
 	*peek_my = sub { +{} } unless __PACKAGE__->can('peek_my');
 }
